# MakePdfEasily

A library that facilitates the process of converting images into a PDF file  <br />
By creating a folder and putting all the images in it and writing the name of the pdf file <br />

مكتبة تعمل على تسهل عملية تحويل صور الى ملف  <br />
 <br />
pdf 
 <br />
عن طريق انشاء مجلد و وضع كل صور فيه و كتابة اسم ملف  <br />
 <br />
pdf 


### to install:
```bash
pip3 install MakePdfEasily
or 
pip install MakePdfEasily
```
### Examples

```bash
import MakePdfEasily 

from  MakePdfEasily import *
#Create a folder first and put all the pictures in it
print(MakePdf("folder","hi.pdf"))

#Merge pdf files

print(mergerPDf("folder","hi.pdf"))
```
